<?php
defined('BASEPATH') or exit('No direct script access allowed');

class ADMIN_Controller extends CI_Controller
{
    public $admindir = '';
    public $theme;
    public $content;

    public function __construct()
    {
        parent::__construct();

        date_default_timezone_set('Asia/Jakarta');

        $this->load->model('MasterModel', 'model');
        $this->load->model('AksesModel', 'akses');

        if (empty($this->session->userdata('id_user'))) {
            if (strcmp($this->router->class, 'login') <> 0) {
                redirect(base_url($this->admindir.'/login'));
            }
        } else {
            if (strcmp($this->router->class, 'login') == 0 and strcmp($this->router->method, 'index') == 0) {
                redirect(base_url($this->admindir.'/home'));
            }
        }

        $mnu = $this->myMenu();
        $this->template->menu($mnu);
    }

    private function myMenu()
    {
        $this->load->config('menu');
        $arrMenu = $this->config->item('menu');

        $menu = '';
        foreach ($arrMenu as $parent) {
            $akses = $this->akses->cekLihat($parent['id']);
            $uri   = str_replace($this->admindir, '', $_SERVER['REQUEST_URI']);

            if (!empty($akses) || (!empty($this->session->userdata('is_admin')))) {
                $aktif = '';
                if (isset($parent['sub'])) {
                    $aktif = $this->activeChild($parent['sub']);
                } else {
                    $aktif = ($uri == $parent['href']) ? ' active' : '';
                }

                $hf	= (strcmp($parent['href'], '#') == 0) ? '#' : $parent['href']; //base_url($this->admindir).

                $menu .= '<li a="'.$uri.'" class="treeview '.$aktif.'">'."\n";
                $menu .= '	<a href="'.$hf.'">'."\n";
                $menu .= '	  <i class="fa '.$parent['ico'].'"></i>'."\n";
                $menu .= '	  <span>'.$parent['text'].'</span>'."\n";
                $menu .= '	  <i class="fa fa-angle-left pull-right"></i>'."\n";
                $menu .= '	</a>'."\n";

                if (isset($parent['sub'])) {
                    $menu .= $this->myChildMenu($parent['sub']);
                }

                $menu .= '</li>'."\n";
            }
        }

        return $menu;
    }

    private function myChildMenu($sub)
    {
        $menu = '<ul class="treeview-menu">';

        foreach ($sub as $sb) {
            $akses = $this->akses->cekLihat($sb['id']);
            $uri   = str_replace($this->admindir, '', $_SERVER['REQUEST_URI']);

            if (!empty($akses) || (!empty($this->session->userdata('is_admin')))) {
                $aktif = '';
                if (isset($sb['sub'])) {
                    $aktif = $this->activeChild($sb['sub']);
                } else {
                    $aktif = ($uri == $sb['href']) ? ' active' : '';
                }

                $menu .= '<li a="'.$uri.'" class="'.$aktif.'">'."\n";

                $hf = (strcmp($sb['href'], '#') == 0) ? '#' : $sb['href']; // base_url($this->admindir).
                $menu .= '	<a href="'.$hf.'">'."\n";

                $menu .= '	  <i class="fa '.$sb['ico'].'"></i>'."\n";
                $menu .= '	  <span>'.$sb['text'].'</span>'."\n";
                $menu .= '	  <i class="fa fa-angle-left pull-right"></i>'."\n";

                $menu .= '	</a>'."\n";

                if (isset($sb['sub'])) {
                    $menu .= $this->myChildMenu($sb['sub']);
                }

                $menu .= '</li>'."\n";
            }
        }

        $menu .= '</ul>'."\n";

        return $menu;
    }

    private function activeChild($sub)
    {
        $aktif = '';
        $uri   = str_replace('/'.$this->admindir, '', $_SERVER['REQUEST_URI']);

        foreach ($sub as $sb) {
            if ($uri == $sb['href']) {
                $aktif = ' active';
                break;
            } else {
                if (isset($sb['sub'])) {
                    $this->activeChild($sb['sub']);
                }
            }
        }
        return $aktif;
    }

    public function getIdentitasPerusahaan()
    {
        return $this->model->get('settingan')->row();
    }

    public function getIdentitasUser($id)
    {
        return $this->model->get('user', null, array('id'=>$id))->row();
    }

    public function getPilihBulan($first=null)
    {
        $this->load->config('date');
        $date = $this->config->item('date');
        $data = $date['bulan'];

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data as $key => $value) {
            $result[$key+1] = $value;
        }

        return $result;
    }

    public function IdPlus($table, $field, $where=null)
    {
        if (isset($where)) {
            $data = $this->model->get($table, $field, $where, $field, 'DESC');
        } else {
            $data = $this->model->get($table, $field, null, $field, 'DESC');
        }

        $id = $data->row($field);

        if (isset($id)) {
            return $id+1;
        } else {
            return 1;
        }
    }

    public function pilihHakAkses($first=null, $where=null)
    {
        if (!empty($where)) {
            $data = $this->model->get('hak_akses', '*', $where);
        } else {
            $data = $this->model->get('hak_akses');
        }

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data->result() as $key) {
            $result[$key->id] = $key->hak_akses;
        }

        return $result;
    }

    public function getUserOption($first=null, $where=null)
    {
        if (!empty($where)) {
            $data = $this->model->get('user', '*', $where);
        } else {
            $data = $this->model->get('user');
        }

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data->result() as $key) {
            $result[$key->id] = $key->nama;
        }

        return $result;
    }

    public function getKategori($first=null)
    {
        $data = $this->model->get('kategori', null, array('is_delete'=>'false'));

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data->result() as $key) {
            $result[$key->id] = $key->kategori;
        }

        return $result;
    }

    public function getMerk($first=null)
    {
        $data = $this->model->get('merk', null, array('is_delete'=>'false'));

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data->result() as $key) {
            $result[$key->id] = $key->merk;
        }

        return $result;
    }

    public function getBarang($first=null, $showOther = null, $where = null)
    {
        $this->load->model('BarangModel', 'barang');
        
        if ($where) {
            $where = array_merge(array('is_delete'=>'false'), $where);

            $data = $this->barang->getPagingBarang($where);
        }
        else
            $data = $this->barang->getPagingBarang();

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data->result() as $key) {
            if (isset($showOther)) {
                $result[$key->id] = $key->nama . ' [ '.$key->$showOther.' ]';
            } else {
                $result[$key->id] = $key->nama;
            }
        }

        return $result;
    }

    public function getCustomer($first=null)
    {
        $data = $this->model->get('customer', null, array('is_delete'=>'false'));

        $result = array();

        if (isset($first)) {
            $result[null] = $first;
        }

        foreach ($data->result() as $key) {
            $result[$key->id] = $key->nama;
        }

        return $result;
    }

    public function cekSameValue($table, $field, $value, $where=null)
    {
        if (isset($where)) {
            $where = array_merge($where, array($field=>$value));

            $data = $this->model->get($table, $field, $where, $field);
        } else {
            $data = $this->model->get($table, $field, array($field=>$value), $field);
        }

        return !empty($data->row()) ? true : false;
    }

    public function newNomor($table, $field, $code, $where=null)
    {
        return $this->model->newNomor($table, $field, $code, $where);
    }
}
