<?php  if (! defined('BASEPATH')) {
    exit('No direct script access allowed');
}

// ------------------------------------------------------------------------

/**
 * MarcoMonteiro Video Helper
 *
 * Serdar Senay (Lupelius)
 * Fix applied where all methods had unnecessary if checks for checking
 * valid ID, removed those as youtube|vimeo_id functions already check that
 * Also added vimeo to _isValidID check, and added vimeo_fullvideo method
 *
 * @package		CodeIgniter
 * @subpackage	Helpers
 * @category	Helpers
 * @author		Marco Monteiro
 * @link			www.marcomonteiro.net
 * @version 	1.0.5
 */

// ------------------------------------------------------------------------

/**
 * Get Youtube Id
 *
 * @access	public
 * @param	string	Youtube url
 * @return	string	Youtube ID
 */
if (! function_exists('youtube_id')) {
    function youtube_id($url = '')
    {
        if ($url === '') {
            return false;
        }
        if (!_isValidURL($url)) {
            return false;
        }

        preg_match("/^(?:http(?:s)?:\/\/)?(?:www\.)?(?:m\.)?(?:youtu\.be\/|youtube\.com\/(?:(?:watch)?\?(?:.*&)?v(?:i)?=|(?:embed|v|vi|user)\/))([^\?&\"'>]+)/", $url, $matches);

        if (!$matches) {
            return false;
        }

        return $matches[1];
    }
}


/**
 * Get Vimeo Id
 *
 * @access	public
 * @param	string	Vimeo url
 * @return	string	Vimeo ID
 */
if (! function_exists('vimeo_id')) {
    function vimeo_id($url = '')
    {
        if ($url === '') {
            return false;
        }
        if (_isValidURL($url)) {
            sscanf(parse_url($url, PHP_URL_PATH), '/%d', $vimeo_id);
        } else {
            $vimeo_id = $url;
        }

        return (_isValidID($vimeo_id, true)) ? $vimeo_id : false;
    }
}


/**
 * Get Youtube thumbs
 *
 * @access	public
 * @param	string	Youtube url || Youtube id
 * @param 	number	1 to 4 to return a specific thumb
 * @return	array		url's to thumbs or specific thumb
 */
if (! function_exists('youtube_thumbs')) {
    function youtube_thumbs($url_id = '', $thumb = '')
    {
        if ($url_id === '') {
            return false;
        }
        if ($thumb > 3 || $thumb < 0) {
            return false;
        }
        if (_isValidID($url_id)) {
            $id = $url_id;
        } else {
            $id = youtube_id($url_id);
        }

        $result = array(
            '0' => 'https://img.youtube.com/vi/'.$id.'/0.jpg',
            '1' => 'https://img.youtube.com/vi/'.$id.'/1.jpg',
            '2' => 'https://img.youtube.com/vi/'.$id.'/2.jpg',
            '3' => 'https://img.youtube.com/vi/'.$id.'/3.jpg'
        );

        if ($thumb === '') {
            return $result;
        } else {
            return $result[$thumb];
        }
    }
}



/**
 * Get Vimeo thumbs
 *
 * @access	public
 * @param	string		Vimeo url || Vimeo id
 * @param 	number 		1 to 3 to return a specific thumb
 * @return	array 		url's to thumbs or specific thumb
 */
if (! function_exists('vimeo_thumbs')) {
    function vimeo_thumbs($url_id = '', $thumb = '')
    {
        if ($url_id == '') {
            return false;
        }
        if ($thumb < 1 || $thumb > 3) {
            return false;
        }
        if (!_isValidURL($url_id)) {
            $id = $url_id;
        } else {
            $id = vimeo_id($url_id);
        }

        $hash = unserialize(file_get_contents("https://vimeo.com/api/v2/video/$id.php"));

        $result = array(
            '0' => $hash[0]['thumbnail_small'],
            '1' => $hash[0]['thumbnail_medium'],
            '2' => $hash[0]['thumbnail_large']
        );

        if ($thumb == '') {
            return $result;
        } else {
            return $result[$thumb];
        }
    }
}

/**
 * Validate URL
 * This URL could have http or just www
 *
 * @access private
 * @param string 		Youtube URL
 * @return preg_match
 */
if (! function_exists('_isValidURL')) {
    function _isValidURL($url = '')
    {
        return preg_match('/^(http|https|ftp):\/\/([A-Z0-9][A-Z0-9_-]*(?:.[A-Z0-9][A-Z0-9_-]*)+):?(d+)?/i', $url);
    }
}

/**
 * Validate ID
 * Check if the id is valid or not
 *
 * @access private
 * @param string 		Youtube ID OR Vimeo ID
 * @return boolean
 */
if (! function_exists('_isValidID')) {
    function _isValidID($id = '', $vimeo=false)
    {
        if ($vimeo) {
            $headers = get_headers('https://vimeo.com/' . $id);
        } else {
            $headers = get_headers('https://gdata.youtube.com/feeds/api/videos/' . $id);
        }
        if (!strpos($headers[0], '200')) {
            return false;
        } else {
            return true;
        }
    }
}

// ------------------------------------------------------------------------

/* End of file video_helper.php */
/* Location: ./application/helpers/video_helper.php */
